@@ -25,8 +25,10 @@
 
 /*
  * $Log: Id3Tag.cs,v $
- * Revision 1.5  2005/11/01 23:32:03  abock
- * Updated entagged tree
+ * Revision 1.8  2005/11/30 16:12:50  abock
+ * 2005-11-30  Aaron Bockover  <aaron@aaronbock.net>
+ *
+ *     * entagged-sharp/*: synced with SVN; (long)Length->(TimeSpan)Duration
  *
  * Revision 1.3  2005/02/08 12:54:42  kikidonk
  * Added cvs log and header
@@ -44,6 +46,7 @@ namespace Entagged.Audioformats.Mp3 {
 		
 		public static byte ID3V22 = 0;
 		public static byte ID3V23 = 1;
+		public static byte ID3V24 = 2;
 		
 		public Id3Tag()
 		{
@@ -53,6 +56,10 @@ namespace Entagged.Audioformats.Mp3 {
 			AddCommonFieldMapping(CommonField.Track, "TRCK");
 			AddCommonFieldMapping(CommonField.Year, "TYER");
 			AddCommonFieldMapping(CommonField.Genre, "TCON");
+			AddCommonFieldMapping(CommonField.License, "TCOP");
+			//AddCommonFieldAlias(CommonField.License, CommonField.Comment);
 		}
+		
+		//representedversion stuff
 	}
 }
