@@ -30,9 +30,10 @@
 using System;
 using Gtk;
 using Mono.Unix;
-
 using System.Runtime.InteropServices;
 
+using Banshee.Base;
+
 namespace Banshee
 {
     public class AboutBox
@@ -46,7 +47,7 @@ namespace Banshee
             "Ben Maurer",
             "Larry Ewing",
             "Miguel de Icaza",
-            "Ulas Sahin",
+            "Aydemir Ula\u015f \u015eahin",
             "Do\u011facan G\u00fcney"
         };
         
@@ -55,6 +56,14 @@ namespace Banshee
             "Jakub Steiner",
             "Ryan Collier"
         };
+        
+        private static string Copyright = Catalog.GetString(
+            "Copyright 2005 Novell, Inc.\n" + 
+             "Copyright 2005 Aaron Bockover"); 
+    
+        private static string Name = Catalog.GetString("Banshee");
+        
+        private static string Comments = Catalog.GetString("Music Management and Playback for Gnome.");
     
         private Translator [] Translators = {
             new Translator("Jordi Mas", "Catalan"),
@@ -67,7 +76,8 @@ namespace Banshee
             new Translator("Vincent van Adrighem", "Dutch"),
             new Translator("\u00D8ivind Hoel", "Norwegian Bokm\u00E5l"),
             new Translator("Marco Carvalho", "Brazilian Portuguese"),
-			new Translator("Christian Rose", "Swedish")
+			new Translator("Christian Rose", "Swedish"),
+			new Translator("Lasse Bang Mikkelsen", "Danish")
         };
     
         private class Translator : IComparable
@@ -113,15 +123,22 @@ namespace Banshee
             Array.Sort(Authors);
             Array.Sort(Artists);
             
+            try {
+                GtkAboutDialog();
+            } catch(Exception) {
+                GnomeAboutDialog();
+            }
+        }
+        
+        private void GtkAboutDialog()
+        {
             GtkSharpBackports.AboutDialog about_dialog = new GtkSharpBackports.AboutDialog();
-            about_dialog.Name = "Banshee";
+            about_dialog.Name = Name;
             about_dialog.Version = ConfigureDefines.VERSION;
-            about_dialog.Copyright = Catalog.GetString(
-                "Copyright 2005 Novell, Inc.\n" + 
-                "Copyright 2005 Aaron Bockover");
-            about_dialog.Comments = Catalog.GetString("Music Management and Playback for Gnome.");
+            about_dialog.Copyright = Copyright;
+            about_dialog.Comments = Comments;
             about_dialog.Website = "http://banshee-project.org/";
-            about_dialog.WebsiteLabel = "Banshee Wiki";
+            about_dialog.WebsiteLabel = Catalog.GetString("Banshee Wiki");
             about_dialog.Authors = Authors;
             about_dialog.TranslatorCredits = Translator.ToString(Translators);
             about_dialog.Artists = Artists;
@@ -132,5 +149,23 @@ namespace Banshee
             about_dialog.Run();
             about_dialog.Destroy();
         }
+        
+#pragma warning disable 0612
+        private void GnomeAboutDialog()
+        {
+            Gnome.About about_dialog = new Gnome.About(
+                Name,
+                ConfigureDefines.VERSION,
+                Copyright,
+                Comments,
+                Authors,
+                null,
+                Translator.ToString(Translators),
+                Gdk.Pixbuf.LoadFromResource("banshee-logo.png"));
+            about_dialog.Run();
+            about_dialog.Destroy();
+        }
+#pragma warning restore 0612
+
     }
 }
