@@ -36,8 +36,9 @@ using Gnome;
 using GConf;
 using Mono.Unix;
 
-using Banshee.Logging;
 using Banshee.FileSystemMonitor;
+using Banshee.Base;
+using Banshee.MediaEngine;
 
 namespace Banshee
 {
@@ -47,7 +48,6 @@ namespace Banshee
 
         public static string [] Args = null;
         public static ArgumentQueue ArgumentQueue = null;
-        public System.Threading.Thread MainThread;
         
         public IPlayerEngine activePlayer;
         public IPlayerEngine PreferredPlayer;
@@ -59,13 +59,11 @@ namespace Banshee
         public DBusServer dbusServer;
         
         public AudioCdCore AudioCdCore;
-        public IpodCore IpodCore;
         
         public string UserRealName;
         public string UserFirstName;
         
         private Library library;
-        private GConf.Client gconfClient;
         private Watcher fs_watcher;
         
         public static Core Instance
@@ -88,7 +86,7 @@ namespace Banshee
         public static GConf.Client GconfClient
         {
             get {
-                return Instance.gconfClient;
+                return Globals.Configuration;
             }
         }
         
@@ -127,7 +125,6 @@ namespace Banshee
 
         private Core()
         {
-            Gdk.Threads.Init();
             Gtk.Application.Init();
 
             Gstreamer.Initialize();
@@ -138,9 +135,10 @@ namespace Banshee
                 Directory.CreateDirectory(Paths.ApplicationData);
 
             Random = new Random();
-            gconfClient = new GConf.Client();
             library = new Library();
 
+            Globals.LibraryLocation = library.Location;
+
             Player = PlayerEngineLoader.SelectedEngine;
             PreferredPlayer = Player;
             
@@ -174,16 +172,17 @@ namespace Banshee
                 Core.Log.PushWarning("Audio CD support will be disabled for this instance", e.Message, false);
             }
             
-            IpodCore = new IpodCore();
+            try {
+                Banshee.Dap.DapCore.Initialize();
+            } catch(ApplicationException e) {
+                Core.Log.PushWarning("DAP support will be disabled for this instance", e.Message, false);
+            }
 
             StockIcons.Initialize();
-            MainThread = System.Threading.Thread.CurrentThread;
-
-            FindUserRealName();
             
             try {
-                if((bool)gconfClient.Get(GConfKeys.EnableFileSystemMonitoring)) {
-                    fs_watcher = new Watcher(gconfClient.Get(GConfKeys.LibraryLocation) as string);
+                if((bool)Globals.Configuration.Get(GConfKeys.EnableFileSystemMonitoring)) {
+                    fs_watcher = new Watcher(Globals.Configuration.Get(GConfKeys.LibraryLocation) as string);
                 } 
             } catch(Exception e) {
                 Core.Log.PushWarning("File System Monitoring will be disabled for this instance", e.Message, false);
@@ -230,147 +229,8 @@ namespace Banshee
             
             library.TransactionManager.CancelAll();
             library.Db.Close();
-            if(AudioCdCore != null) {
-                AudioCdCore.Dispose();
-            }
-            IpodCore.Dispose();
-        }
-        
-        public static bool InMainThread
-        {
-            get {
-                return Core.Instance.MainThread.Equals(
-                    System.Threading.Thread.CurrentThread);
-            }
-        }
-        
-        public static void ProxyToMainThread(EventHandler handler)
-        {
-            if(!InMainThread) {
-                Gtk.Application.Invoke(handler);
-            } else {
-                handler(null, new EventArgs());
-            }
-        }
-        
-        [DllImport("libglib-2.0.so")]
-        static extern IntPtr g_get_real_name();
-
-        private void FindUserRealName()
-        {
-            try {
-                UserRealName = GLib.Marshaller.Utf8PtrToString(g_get_real_name());
-                string[] parts = UserRealName.Split(' ');
-                UserFirstName = parts[0].Replace(',', ' ').Trim();
-            } catch(Exception) { }
-        }
-    }
-    
-    public class UidGenerator
-    {
-        private static int uid = 0;
-        
-        public static int Next
-        {
-            get {
-                return ++uid;
-            }
-        }
-    
-    }
-
-    public class ArgumentLayout
-    {
-        public string Name, ValueKind, Description;
-        
-        public ArgumentLayout(string name, string description) : this(name, 
-            null, description)
-        {
-    
-        }
-        
-        public ArgumentLayout(string name, string valueKind, string description)
-        {
-            Name = name;
-            ValueKind = valueKind;
-            Description = description;
-        }
-    }
-
-    public class ArgumentQueue : IEnumerable
-    {
-        private ArgumentLayout [] availableArgs; 
-        private Hashtable args = new Hashtable();
-
-        public ArgumentQueue(ArgumentLayout [] availableArgs, string [] args)
-        {
-            this.availableArgs = availableArgs;
-        
-            for(int i = 0; i < args.Length; i++) {
-                string arg = null, val = String.Empty;
-                
-                if(args[i].StartsWith("--")) {
-                    arg = args[i].Substring(2);
-                }
-
-                if(i < args.Length - 1) {
-                    if(!args[i + 1].StartsWith("--")) {
-                        val = args[i + 1];
-                        i++;
-                    }
-                }
-
-                if(arg != null) {
-                    Enqueue(arg, val);
-                }
-            }
-        }
-
-        public void Enqueue(string arg)
-        {
-            Enqueue(arg, String.Empty);
-        }
-
-        public void Enqueue(string arg, string val)
-        {
-            args.Add(arg, val);
-        }
-
-        public void Dequeue(string arg)
-        {
-            args.Remove(arg);
-        }
-
-        public bool Contains(string arg)
-        {
-            return args[arg] != null;
-        }
-
-        public string this [string arg]
-        {
-            get {
-                return args[arg] as string;
-            }
-        }
-
-        public IEnumerator GetEnumerator()
-        {
-            return args.GetEnumerator();
-        }
-
-        public string [] Arguments 
-        {
-            get {
-                ArrayList list = new ArrayList(args.Keys);
-                return list.ToArray(typeof(string)) as string [];
-            }
-        }
-
-        public ArgumentLayout [] AvailableArguments
-        {
-            get {
-                return availableArgs;
-            }
+            
+            HalCore.Dispose();
         }
     }
 }
