@@ -29,7 +29,7 @@
 
 using System;
 using Gnome;
-
+using Banshee.Base;
 namespace Banshee
 {    
     public class BansheeEntry
@@ -73,6 +73,12 @@ namespace Banshee
                 new ArgumentLayout("version", "Show Banshee Version")
             }, args);
 
+            if(Core.ArgumentQueue.Contains("print-todo")) {
+                BansheeTodo.PrintReport();
+                Console.WriteLine("");
+                System.Environment.Exit(0);
+            }
+            
             if(Core.ArgumentQueue.Contains("help")) {
                 int maxNameLen = 0;
                 int maxVarLen = 0;
@@ -220,6 +226,7 @@ namespace Banshee
             Core.Args = args;
             Core.Instance.Program = new Program(appname, version, Modules.UI, args);
             new Banshee.PlayerUI();
+            Gtk.Application.Run();
         }
     }
 }
