@@ -38,8 +38,10 @@ using Glade;
 using System.IO;
 
 using Sql;
-using Banshee.Logging;
 using Banshee.Widgets;
+using Banshee.Base;
+using Banshee.MediaEngine;
+using Banshee.Dap;
 
 namespace Banshee
 {
@@ -75,17 +77,17 @@ namespace Banshee
         private SearchEntry searchEntry;
         private Tooltips toolTips;
         private Hashtable playlistMenuMap;
-        private ProgressBar ipodDiskUsageBar;
+        private ProgressBar dapDiskUsageBar;
         private Viewport sourceViewLoadingVP;
-        private Button ipodSyncButton;
-        private Button ipodPropertiesButton;
-        private Button ipodEjectButton;
+        private Button dapSyncButton;
+        private Button dapPropertiesButton;
+        private Button dapEjectButton;
             
         private MultiStateToggleButton repeat_toggle_button;
         private MultiStateToggleButton shuffle_toggle_button;
                 
         private EventBox syncing_container;
-        private Gtk.Image ipod_syncing_image = new Gtk.Image();
+        private Gtk.Image dap_syncing_image = new Gtk.Image();
             
         private CoverArtThumbnail cover_art;
         
@@ -98,8 +100,6 @@ namespace Banshee
             }
         }
         
-        private IpodCore ipodCore = Core.Instance.IpodCore;
-        
         private long plLoaderMax, plLoaderCount;
         private bool startupLoadReady = false;
         private bool tickFromEngine = false;
@@ -107,7 +107,9 @@ namespace Banshee
         private bool updateEnginePosition = true;
         private int clickX, clickY;
 
-        private int ipodDiskUsageTextViewState;
+        private int dapDiskUsageTextViewState;
+        
+        private SpecialKeys special_keys;
 
         private static TargetEntry [] playlistViewSourceEntries = 
             new TargetEntry [] {
@@ -146,7 +148,6 @@ namespace Banshee
             Core.Instance.DBusServer.RegisterObject(
                 new BansheeCore(Window, this, Core.Instance), "/org/gnome/Banshee/Core");
                         
-            WindowPlayer.Show();
             
             Core.Instance.Player.Iterate += OnPlayerTick;
             Core.Instance.Player.EndOfStream += OnPlayerEos;    
@@ -161,28 +162,42 @@ namespace Banshee
                 Core.Instance.AudioCdCore.Updated += OnAudioCdCoreUpdated;
             }
             
-            Core.Instance.IpodCore.DeviceAdded += OnIpodCoreDeviceAdded;
+            DapCore.DapAdded += OnDapCoreDeviceAdded;
             
             LoadSettings();
             Core.Instance.PlayerInterface = this;
             
             Core.Log.Updated += OnLogCoreUpdated;
             
-            InitialLoadTimeout();
-            //GLib.Timeout.Add(500, InitialLoadTimeout);
-    
-            Gtk.Application.Run();
+            //InitialLoadTimeout();
+            GLib.Timeout.Add(500, InitialLoadTimeout);
+            WindowPlayer.Show();
+            
+            try {
+                if((bool)Globals.Configuration.Get(GConfKeys.EnableSpecialKeys)) {
+                    special_keys = new SpecialKeys();
+                    special_keys.Delay = new TimeSpan(350 * TimeSpan.TicksPerMillisecond);
+                    special_keys.RegisterHandler(OnSpecialKeysPressed, 
+                        SpecialKey.AudioPlay,
+                        SpecialKey.AudioPrev,
+                        SpecialKey.AudioNext
+                    );
+                }
+            } catch(GConf.NoSuchKeyException) {
+            } catch(Exception e) {
+                special_keys = null;
+                Core.Log.PushWarning(Catalog.GetString("Could not setup special keys"), e.Message, false);
+            }   
         }
-                  
+   
         private bool InitialLoadTimeout()
         {
             ConnectToLibraryTransactionManager();
             Core.Library.Reloaded += OnLibraryReloaded;
             Core.Library.ReloadLibrary();
             
-            foreach(IPod.Device device in Core.Instance.IpodCore.Devices) {
-                 device.Changed += OnIpodDeviceChanged;
-                 CheckIpodForNew(device);
+            foreach(DapDevice device in DapCore.Devices) {
+                 device.PropertiesChanged += OnDapPropertiesChanged;
             }
             
             if(Core.ArgumentQueue.Contains("audio-cd")) {
@@ -203,7 +218,7 @@ namespace Banshee
                 y = (int)Core.GconfClient.Get(GConfKeys.WindowY); 
                 width = (int)Core.GconfClient.Get(GConfKeys.WindowWidth);
                 height = (int)Core.GconfClient.Get(GConfKeys.WindowHeight);
-            } catch(GConf.NoSuchKeyException e) {
+            } catch(GConf.NoSuchKeyException) {
                 width = 800;
                 height = 600;
                 x = 0;
@@ -219,7 +234,24 @@ namespace Banshee
             } else {
                 WindowPlayer.Move(x, y);
             }
-        }   
+            
+            try {
+                if((bool)Core.GconfClient.Get(GConfKeys.WindowMaximized)) {
+                    WindowPlayer.Maximize();
+                } else {
+                    WindowPlayer.Unmaximize();
+                }
+            } catch(GConf.NoSuchKeyException) {
+            }
+        }
+        
+        private void OnWindowStateEvent(object o, WindowStateEventArgs args)
+        {
+            if((args.Event.NewWindowState & Gdk.WindowState.Withdrawn) == 0) {
+                Globals.Configuration.Set(GConfKeys.WindowMaximized,
+                    (args.Event.NewWindowState & Gdk.WindowState.Maximized) != 0);
+            }
+        }
           
         private void BuildWindow()
         {
@@ -316,39 +348,39 @@ namespace Banshee
                 playlistViewDestEntries, 
                 DragAction.Copy | DragAction.Move);
             
-            // Ipod Container
+            // Dap Container
             HBox box = new HBox();
             box.Spacing = 5;
-            (gxml["IpodContainer"] as Container).Add(box);
-            ipodDiskUsageBar = new ProgressBar();
-            box.PackStart(ipodDiskUsageBar, false, false, 0);
-            ipodDiskUsageBar.ShowAll();
+            (gxml["DapContainer"] as Container).Add(box);
+            dapDiskUsageBar = new ProgressBar();
+            box.PackStart(dapDiskUsageBar, false, false, 0);
+            dapDiskUsageBar.ShowAll();
             
             HBox syncBox = new HBox();
             syncBox.Spacing = 3;
-            ipodSyncButton = new Button(syncBox);
-            Label syncLabel = new Label(Catalog.GetString("Update iPod"));
-            ipodSyncButton.Clicked += OnIpodSyncClicked;
+            dapSyncButton = new Button(syncBox);
+            Label syncLabel = new Label(Catalog.GetString("Update Device"));
+            dapSyncButton.Clicked += OnDapSyncClicked;
             syncBox.PackStart(new Gtk.Image("gtk-copy", IconSize.Menu), false, false, 0);
             syncBox.PackStart(syncLabel, true, true, 0);
-            box.PackStart(ipodSyncButton, false, false, 0);
-            ipodSyncButton.ShowAll();
+            box.PackStart(dapSyncButton, false, false, 0);
+            dapSyncButton.ShowAll();
             
-            ipodPropertiesButton = new Button(
+            dapPropertiesButton = new Button(
                 new Gtk.Image("gtk-properties", IconSize.Menu));
-            ipodPropertiesButton.Clicked += OnIpodPropertiesClicked;
-            box.PackStart(ipodPropertiesButton, false, false, 0);
-            ipodPropertiesButton.ShowAll();
+            dapPropertiesButton.Clicked += OnDapPropertiesClicked;
+            box.PackStart(dapPropertiesButton, false, false, 0);
+            dapPropertiesButton.ShowAll();
             
-            ipodEjectButton = new Button(new Gtk.Image("media-eject",
+            dapEjectButton = new Button(new Gtk.Image("media-eject",
                 IconSize.Menu));
-            ipodEjectButton.Clicked += OnIpodEjectClicked;
-            box.PackStart(ipodEjectButton, false, false, 0);
-            ipodEjectButton.ShowAll();
+            dapEjectButton.Clicked += OnDapEjectClicked;
+            box.PackStart(dapEjectButton, false, false, 0);
+            dapEjectButton.ShowAll();
             
             (gxml["LeftContainer"] as VBox).PackStart(new ActiveUserEventsManager(), false, false, 0);
             
-           // gxml["IpodContainer"].Visible = false;
+           // gxml["DapContainer"].Visible = false;
             
             // Misc
             SetInfoLabel(Catalog.GetString("Idle"));
@@ -356,6 +388,7 @@ namespace Banshee
             // Window Events
             WindowPlayer.KeyPressEvent += OnKeyPressEvent;
             WindowPlayer.ConfigureEvent += OnWindowPlayerConfigureEvent;
+            WindowPlayer.WindowStateEvent += OnWindowStateEvent;
             
             // Search Entry
             ArrayList fields = new ArrayList();
@@ -410,11 +443,11 @@ namespace Banshee
             SetTip(gxml["ButtonNext"], Catalog.GetString("Play Next Song"));
             SetTip(gxml["ScaleTime"], Catalog.GetString("Current Position in Song"));
             SetTip(volumeButton, Catalog.GetString("Adjust Volume"));
-            SetTip(ipodDiskUsageBar, Catalog.GetString("iPod Disk Usage"));
-            SetTip(ipodEjectButton, Catalog.GetString("Eject iPod"));
-            SetTip(ipodSyncButton, Catalog.GetString("Synchronize Music Library to iPod"));
-            SetTip(gxml["IpodSyncButton"], Catalog.GetString("Synchronize Music Library to iPod"));
-            SetTip(ipodPropertiesButton, Catalog.GetString("View iPod Properties"));
+            SetTip(dapDiskUsageBar, Catalog.GetString("Device Disk Usage"));
+            SetTip(dapEjectButton, Catalog.GetString("Eject Device"));
+            SetTip(dapSyncButton, Catalog.GetString("Synchronize Music Library to Device"));
+            SetTip(gxml["DapSyncButton"], Catalog.GetString("Synchronize Music Library to Device"));
+            SetTip(dapPropertiesButton, Catalog.GetString("View Device Properties"));
             
             playlistMenuMap = new Hashtable();
         }
@@ -440,8 +473,6 @@ namespace Banshee
                 trayIcon.PlayItem.Activated += OnButtonPlayPauseClicked;
                 trayIcon.NextItem.Activated += OnButtonNextClicked;
                 trayIcon.PreviousItem.Activated += OnButtonPreviousClicked;
-                trayIcon.ShuffleItem.Activated += OnTrayMenuItemShuffleActivated;
-                trayIcon.RepeatItem.Activated += OnTrayMenuItemRepeatActivated;
                 trayIcon.ExitItem.Activated += OnMenuQuitActivate;
             } catch(Exception e) {
                 trayIcon = null;
@@ -645,8 +676,11 @@ namespace Banshee
             trackInfoHeader.Artist = ti.DisplayArtist;
             trackInfoHeader.Title = ti.DisplayTitle;
             
-            cover_art.Label = String.Format("{0} - {1}", ti.Artist, ti.Album);
-            cover_art.FileName = ti.CoverArtFileName;
+            try {
+                cover_art.FileName = ti.CoverArtFileName;
+                cover_art.Label = String.Format("{0} - {1}", ti.Artist, ti.Album);
+            } catch(Exception) {
+            }
             
             if(trayIcon != null) {
                 trayIcon.Tooltip = ti.DisplayArtist + " - " + ti.DisplayTitle;
@@ -668,7 +702,7 @@ namespace Banshee
 
             incrementedCurrentSongPlayCount = false;
             ScaleTime.Adjustment.Lower = 0;
-            ScaleTime.Adjustment.Upper = ti.Duration;
+            ScaleTime.Adjustment.Upper = ti.Duration.TotalSeconds;
 
             UpdateMetaDisplay(ti);
             
@@ -691,16 +725,13 @@ namespace Banshee
         {
             int x, y, width, height;
 
-            // Ignore events when maximized.
-            if((WindowPlayer.GdkWindow.State & Gdk.WindowState.Maximized) > 0) {
+            if((WindowPlayer.GdkWindow.State & Gdk.WindowState.Maximized) != 0) {
                 return;
             }
             
             WindowPlayer.GetPosition(out x, out y);
             WindowPlayer.GetSize(out width, out height);
             
-            // might consider putting this in some kind of time delay queue
-            // so we're not writing to the gconf client every pixel change
             Core.GconfClient.Set(GConfKeys.WindowX, x);
             Core.GconfClient.Set(GConfKeys.WindowY, y);
             Core.GconfClient.Set(GConfKeys.WindowWidth, width);
@@ -845,6 +876,21 @@ namespace Banshee
             playlistView.UpdateView();
         }
         
+        private void OnSpecialKeysPressed(object o, SpecialKey key)
+        {
+            switch(key) {
+                case SpecialKey.AudioPlay:
+                    PlayPause();
+                    break;
+                case SpecialKey.AudioNext:
+                    Next();
+                    break;
+                case SpecialKey.AudioPrev:
+                    Previous();
+                    break;
+            }
+        }
+        
         private void OnButtonPreviousClicked(object o, EventArgs args)
         {
             if(Core.Instance.Player.Position < 3) {
@@ -946,8 +992,8 @@ namespace Banshee
                 // Translators: position in song. eg, "0:37 of 3:48"
                 String.Format(Catalog.GetString("{0} of {1}"),
                           String.Format("{0}:{1:00}", position / 60, position % 60),
-                          String.Format("{0}:{1:00}", activeTrackInfo.Duration / 60, 
-                          activeTrackInfo.Duration % 60))
+                          String.Format("{0}:{1:00}", activeTrackInfo.Duration.Minutes, 
+                          activeTrackInfo.Duration.Seconds))
             );    
         }
         
@@ -958,11 +1004,11 @@ namespace Banshee
             }
              
             if(Core.Instance.Player.Length > 0 
-                && activeTrackInfo.Duration <= 0) {
-                activeTrackInfo.Duration = Core.Instance.Player.Length;
+                && activeTrackInfo.Duration.TotalSeconds <= 0.0) {
+                activeTrackInfo.Duration = new TimeSpan(Core.Instance.Player.Length * TimeSpan.TicksPerSecond);
                 activeTrackInfo.Save();
                 playlistView.ThreadedQueueDraw();
-                ScaleTime.Adjustment.Upper = activeTrackInfo.Duration;
+                ScaleTime.Adjustment.Upper = activeTrackInfo.Duration.TotalSeconds;
             }
                 
             if(Core.Instance.Player.Length > 0 && 
@@ -1166,7 +1212,7 @@ namespace Banshee
                 return;
             }
             
-            gxml["ItemRemoveSongsFileSystem"].Sensitive = !(source is AudioCdSource || source is IpodSource) && have_selection;
+            gxml["ItemRemoveSongsFileSystem"].Sensitive = !(source is AudioCdSource || source is DapSource) && have_selection;
             gxml["ItemRemoveSongs"].Sensitive = !(source is AudioCdSource) && have_selection;
             gxml["MenuTrackProperties"].Sensitive = have_selection;
             gxml["ButtonTrackProperties"].Sensitive = have_selection;
@@ -1176,11 +1222,7 @@ namespace Banshee
         
         private void OnSourceChanged(object o, EventArgs args)
         {
-            if(Core.InMainThread) {
-                HandleSourceChanged(o, args);
-            } else {
-                Application.Invoke(HandleSourceChanged);
-            }
+            ThreadAssist.ProxyToMain(HandleSourceChanged);
         }
         
         private void HandleSourceChanged(object o, EventArgs args)
@@ -1199,14 +1241,12 @@ namespace Banshee
                 (gxml["ViewNameLabel"] as Label).Markup = 
                     String.Format(Catalog.GetString("<b>{0}'s Music Library</b>"),
                     GLib.Markup.EscapeText(Core.Instance.UserFirstName));
-            } else if(source.Type == SourceType.Ipod) {
+            } else if(source.Type == SourceType.Dap) {
                 playlistModel.Clear();
                 playlistModel.Source = source;
-                
-                IpodSource ipodSource = source as IpodSource;
-                playlistModel.LoadFromIpodSource(ipodSource);
-                
-                UpdateIpodDiskUsageBar(ipodSource);
+                DapSource dap_source = source as DapSource;
+                playlistModel.LoadFromDapSource(dap_source);
+                UpdateDapDiskUsageBar(dap_source);
             } else if(source.Type == SourceType.AudioCd) {
                 playlistModel.Clear();
                 playlistModel.Source = source;
@@ -1223,31 +1263,31 @@ namespace Banshee
 
             gxml["ButtonRip"].Visible = source.Type == SourceType.AudioCd;
             gxml["ButtonBurn"].Visible = source.Type != SourceType.AudioCd;
-            gxml["IpodSyncButton"].Visible = source.Type == SourceType.Ipod;
+            gxml["DapSyncButton"].Visible = source.Type == SourceType.Dap;
             (gxml["HeaderActionButtonBox"] as HBox).Spacing = (
-                gxml["ButtonBurn"].Visible && gxml["IpodSyncButton"].Visible) ?  10 : 0;
+                gxml["ButtonBurn"].Visible && gxml["DapSyncButton"].Visible) ?  10 : 0;
             
-            if(source.Type == SourceType.Ipod) {
-                gxml["IpodContainer"].ShowAll();
-                IpodSource ipodSource = source as IpodSource;
-                ipodSyncButton.Visible = ipodSource.Device.CanWrite;
-                ((Gtk.Image)gxml["ImageIpodSync"]).Pixbuf = IpodMisc.GetIcon(ipodSource.Device, 24);
+            if(source.Type == SourceType.Dap) {
+                gxml["DapContainer"].ShowAll();
+                DapSource dapSource = source as DapSource;
+                dapSyncButton.Visible = !dapSource.Device.IsReadOnly;
+                ((Gtk.Image)gxml["ImageDapSync"]).Pixbuf = dapSource.Device.GetIcon(22);
             } else {
-                gxml["IpodContainer"].Visible = false;
+                gxml["DapContainer"].Visible = false;
             }     
                  
-            gxml["SearchLabel"].Sensitive = source.Type == SourceType.Ipod 
+            gxml["SearchLabel"].Sensitive = source.Type == SourceType.Dap 
                  || source.Type == SourceType.Library;
             searchEntry.Sensitive = gxml["SearchLabel"].Sensitive;
-            playlistView.SyncColumn.Visible = source.Type == SourceType.Ipod;
+            playlistView.SyncColumn.Visible = source.Type == SourceType.Dap;
             playlistView.RipColumn.Visible = source.Type == SourceType.AudioCd;
             
             playlistModel.ImportCanUpdate = source.Type == SourceType.Library
                 && searchEntry.Query == String.Empty;
                 
-            if(source.Type != SourceType.Ipod)
+            if(source.Type != SourceType.Dap)
                 ShowPlaylistView();
-            else if((source as IpodSource).IsSyncing)
+            else if((source as DapSource).IsSyncing)
                 ShowSyncingView();
             else
                 ShowPlaylistView();
@@ -1259,41 +1299,30 @@ namespace Banshee
             gxml["ItemImportCD"].Sensitive = source is AudioCdSource;
         }
         
-        private void UpdateIpodDiskUsageBar(IpodSource ipodSource)
+        private void UpdateDapDiskUsageBar(DapSource dapSource)
         {
             Application.Invoke(delegate {
-            ipodDiskUsageBar.Fraction = ipodSource.DiskUsageFraction;
-            ipodDiskUsageBar.Text = ipodSource.DiskUsageString;
-            string tooltip = ipodSource.DiskUsageString + " (" +
-                ipodSource.DiskAvailableString + ")";
-            toolTips.SetTip(ipodDiskUsageBar, tooltip, tooltip);
+                dapDiskUsageBar.Fraction = dapSource.DiskUsageFraction;
+                dapDiskUsageBar.Text = dapSource.DiskUsageString;
+                string tooltip = dapSource.DiskUsageString + " (" + dapSource.DiskAvailableString + ")";
+                toolTips.SetTip(dapDiskUsageBar, tooltip, tooltip);
             });
         }
         
-        private void CheckIpodForNew(IPod.Device device)
+        private void OnDapPropertiesChanged(object o, EventArgs args)
         {
-          if(device.IsNew) {
-              Application.Invoke(delegate {
-                new IpodNewDialog(device);
-                 sourceView.QueueDraw();
-              });
-           }
-        }
-        
-        private void OnIpodDeviceChanged(object o, EventArgs args)
-        {
-            Application.Invoke (delegate {
-                IPod.Device device = o as IPod.Device;
+            Application.Invoke(delegate {
+                DapDevice device = o as DapDevice;
                 
                 foreach(object [] obj in (sourceView.Model as ListStore)) {
-                    if(obj[0] is IpodSource && (obj[0] as IpodSource).Device == device) {
-                        (obj[0] as IpodSource).SetSourceName(device.Name);
+                    if(obj[0] is DapSource && (obj[0] as DapSource).Device == device) {
+                        (obj[0] as DapSource).SetSourceName(device.Name);
                         sourceView.QueueDraw();
                     }
                 }
                 
-                if(playlistModel.Source is IpodSource && (playlistModel.Source as IpodSource).Device == device) {
-                    UpdateIpodDiskUsageBar(playlistModel.Source as IpodSource);
+                if(playlistModel.Source is DapSource && (playlistModel.Source as DapSource).Device == device) {
+                    UpdateDapDiskUsageBar(playlistModel.Source as DapSource);
                     (gxml["ViewNameLabel"] as Label).Markup = "<b>" 
                         + GLib.Markup.EscapeText(device.Name) + "</b>";
                     sourceView.QueueDraw();
@@ -1301,10 +1330,9 @@ namespace Banshee
             });
         }
         
-        private void OnIpodCoreDeviceAdded(object o, IpodDeviceArgs args)
+        private void OnDapCoreDeviceAdded(object o, DapEventArgs args)
         {
-            args.Device.Changed += OnIpodDeviceChanged;
-            CheckIpodForNew(args.Device);
+            args.Dap.PropertiesChanged += OnDapPropertiesChanged;
         }
         
         private void OnAudioCdCoreDiskRemoved(object o, AudioCdCoreDiskRemovedArgs args)
@@ -1336,8 +1364,7 @@ namespace Banshee
                     && playlistModel.FirstTrack.GetType() == 
                     typeof(AudioCdTrackInfo)) {
                     AudioCdSource cdSource = source as AudioCdSource;
-                    AudioCdTrackInfo track = playlistModel.FirstTrack 
-                        as AudioCdTrackInfo;
+                    AudioCdTrackInfo track = playlistModel.FirstTrack as AudioCdTrackInfo;
                     
                     if(cdSource.Disk.DeviceNode == track.Device) 
                         (gxml["ViewNameLabel"] as Label).Markup = 
@@ -1346,25 +1373,30 @@ namespace Banshee
             });
         }
         
-        private void OnIpodPropertiesClicked(object o, EventArgs args)
+        private void OnDapPropertiesClicked(object o, EventArgs args)
         {
-            if(sourceView.SelectedSource.Type != SourceType.Ipod)
+            if(sourceView.SelectedSource.Type != SourceType.Dap)
                 return;
             
-            ShowSourceProperties(sourceView.SelectedSource);
+            //ShowSourceProperties(sourceView.SelectedSource);
         }
         
-        private void OnIpodSyncButtonClicked(object o, EventArgs args)
+        private void OnDapSyncButtonClicked(object o, EventArgs args)
         {
-            OnIpodSyncClicked(o, args);
+            OnDapSyncClicked(o, args);
         }
         
-        private void OnIpodSyncClicked(object o, EventArgs args)
+        private void OnDapSyncClicked(object o, EventArgs args)
         {
-            if(sourceView.SelectedSource.Type != SourceType.Ipod)
+            if(sourceView.SelectedSource.Type != SourceType.Dap)
                 return;
+                
+           LogCore.Instance.PushWarning(Catalog.GetString("iPod Syncing Disabled"), 
+                Catalog.GetString("iPod syncing has been disabled in this release because unified DAP " + 
+                "support is under development, and the iPod sync code has not yet been converted to " + 
+                "the DAP sync model. iPod syncing will be back in the next release."));
         
-            IpodSource ipodSource = sourceView.SelectedSource as IpodSource;
+           /* IpodSource ipodSource = sourceView.SelectedSource as IpodSource;
             IpodSync sync = null;
             
             if(!ipodSource.Device.CanWrite)
@@ -1420,43 +1452,43 @@ namespace Banshee
                 }
                 
                 md.Destroy();
-            }
+            }*/
         }
         
-        private void OnIpodEjectClicked(object o, EventArgs args)
+        private void OnDapEjectClicked(object o, EventArgs args)
         {
             EjectSource(sourceView.SelectedSource);
         }
         
-        private void OnIpodSyncStarted(object o, EventArgs args)
+        private void OnDapSyncStarted(object o, EventArgs args)
         {
-            if(playlistModel.Source.Type == SourceType.Ipod 
-                && (playlistModel.Source as IpodSource).IsSyncing) {
+            if(playlistModel.Source.Type == SourceType.Dap 
+                && (playlistModel.Source as DapSource).IsSyncing) {
                 ShowSyncingView();
-                ipodSyncButton.Sensitive = false;
-                ipodPropertiesButton.Sensitive = false;
-                ipodEjectButton.Sensitive = false;
-                gxml["IpodSyncButton"].Sensitive = false;
+                dapSyncButton.Sensitive = false;
+                dapPropertiesButton.Sensitive = false;
+                dapEjectButton.Sensitive = false;
+                gxml["DapSyncButton"].Sensitive = false;
                 gxml["SearchLabel"].Sensitive = false;
                 searchEntry.Sensitive = false;
-                ipod_syncing_image.Pixbuf = IpodMisc.GetIcon((playlistModel.Source as IpodSource).Device, 128);
+                dap_syncing_image.Pixbuf = (playlistModel.Source as DapSource).Device.GetIcon(128);
             }
         }
         
-        private void OnIpodSyncCompleted(object o, EventArgs args)
+        private void OnDapSyncCompleted(object o, EventArgs args)
         {
-            if(playlistModel.Source.Type == SourceType.Ipod 
-                && !(playlistModel.Source as IpodSource).IsSyncing) {
+            if(playlistModel.Source.Type == SourceType.Dap 
+                && !(playlistModel.Source as DapSource).IsSyncing) {
                 //playlistView.Show();
                 //playlistView.QueueDraw();
                 ShowPlaylistView();
-                ipodSyncButton.Sensitive = true;
-                ipodPropertiesButton.Sensitive = true;
-                ipodEjectButton.Sensitive = true;
-                gxml["IpodSyncButton"].Sensitive = true;
+                dapSyncButton.Sensitive = true;
+                dapPropertiesButton.Sensitive = true;
+                dapEjectButton.Sensitive = true;
+                gxml["DapSyncButton"].Sensitive = true;
                 gxml["SearchLabel"].Sensitive = true;
                 searchEntry.Sensitive = true;
-                playlistModel.LoadFromIpodSource((playlistModel.Source as IpodSource));
+                playlistModel.LoadFromDapSource((playlistModel.Source as DapSource));
             }
             
             sourceView.QueueDraw();
@@ -1485,7 +1517,7 @@ namespace Banshee
         private void OnPlaylistUpdated(object o, EventArgs args)
         {
             long count = playlistModel.Count();
-            TimeSpan span = new TimeSpan(playlistModel.TotalDuration * TimeSpan.TicksPerSecond);        
+            TimeSpan span = playlistModel.TotalDuration;       
             string timeDisp = String.Empty;
             
             if(span.Days > 0) {
@@ -1500,7 +1532,7 @@ namespace Banshee
                 timeDisp += String.Format("{0}:{1}", span.Minutes, span.Seconds.ToString("00"));
             }
             
-            Core.ProxyToMainThread(delegate {
+            ThreadAssist.ProxyToMain(delegate {
                 if(count == 0 && playlistModel.Source == null) {
                     LabelStatusBar.Text = Catalog.GetString("Banshee Music Player");
                 } else if(count == 0) {
@@ -1635,13 +1667,13 @@ namespace Banshee
             
             TrackRemoveTransaction transaction;
             
-            if(playlistModel.Source.Type == SourceType.Ipod) {
+            if(playlistModel.Source.Type == SourceType.Dap) {
                 for(i = 0; i < iters.Length; i++) {
                     TrackInfo ti = playlistModel.IterTrackInfo(iters[i]);
                     playlistModel.RemoveTrack(ref iters[i]);
                     
-                    IpodTrackInfo iti = ti as IpodTrackInfo;
-                    (playlistModel.Source as IpodSource).Remove(iti);
+                    DapTrackInfo iti = ti as DapTrackInfo;
+                    (playlistModel.Source as DapSource).Device.RemoveTrack(iti);
                 }
                 sourceView.QueueDraw();
                 return;
@@ -1749,7 +1781,7 @@ namespace Banshee
             //    && playlistView.Selection.CountSelectedRows() > 0;
             addSelectedSongs.Visible = false;
             
-            sourceProperties.Visible = source.Type == SourceType.Ipod;
+            sourceProperties.Visible = source.Type == SourceType.Dap;
           
             if(source.CanEject) {
                 ejectItem.Image = new Gtk.Image("media-eject", IconSize.Menu);
@@ -1759,7 +1791,7 @@ namespace Banshee
             menu.Show();
             
             addSelectedSongs.Visible = source.Type == SourceType.Playlist ||
-             source.Type == SourceType.Ipod;
+             source.Type == SourceType.Dap;
             
             sourceDuplicate.Visible = false;
             ejectItem.Visible = source.CanEject;
@@ -1838,12 +1870,12 @@ namespace Banshee
                     Catalog.GetString("Rename Playlist"),
                     Catalog.GetString("Enter new playlist name"), 
                     Gdk.Pixbuf.LoadFromResource("playlist-icon-large.png"), source.Name);
-            } else if(source.Type == SourceType.Ipod) {
-                IpodSource ipod_source = source as IpodSource;
+            } else if(source.Type == SourceType.Dap) {
+                DapSource dap_source = source as DapSource;
                 input = new InputDialog(
-                    Catalog.GetString("Rename iPod"),
-                    Catalog.GetString("Enter new name for your iPod"),
-                    IpodMisc.GetIcon(ipod_source.Device, 48), source.Name);
+                    Catalog.GetString("Rename Device"),
+                    Catalog.GetString("Enter new name for your device"),
+                    dap_source.Device.GetIcon(48), source.Name);
             } else {
                 return;
             }
@@ -1905,8 +1937,8 @@ namespace Banshee
                 query == null || query == String.Empty;
             
             if(query == null || query == String.Empty) {
-                if(source.Type == SourceType.Ipod)
-                    playlistModel.LoadFromIpodSource(source as IpodSource);
+                if(source.Type == SourceType.Dap)
+                    playlistModel.LoadFromDapSource(source as DapSource);
                 else
                     playlistModel.LoadFromLibrary();
                 
@@ -1917,8 +1949,8 @@ namespace Banshee
             
             ICollection collection = null;
             
-            if(source.Type == SourceType.Ipod) {
-                collection = (source as IpodSource).Tracks;
+            if(source.Type == SourceType.Dap) {
+                collection = (source as DapSource).Device.Tracks;
             } else {
                 collection = Core.Library.Tracks.Values;
             }
@@ -2126,7 +2158,7 @@ namespace Banshee
             gxmlPlaylistMenu["ItemRemove"].Visible = sensitive
                 && playlistModel.Source.Type != SourceType.AudioCd;
             gxmlPlaylistMenu["ItemDeleteSongsFileSystem"].Visible = sensitive 
-                && playlistModel.Source.Type != SourceType.Ipod 
+                && playlistModel.Source.Type != SourceType.Dap 
                 && playlistModel.Source.Type != SourceType.AudioCd;
             gxmlPlaylistMenu["ItemProperties"].Visible = sensitive;
             
@@ -2341,8 +2373,8 @@ namespace Banshee
         {
             if(source.CanEject) {
                 try {
-                    if(source.GetType() == typeof(IpodSource)) {
-                        if(activeTrackInfo != null && activeTrackInfo is IpodTrackInfo) {
+                    if(source.GetType() == typeof(DapSource)) {
+                        if(activeTrackInfo != null && activeTrackInfo is DapTrackInfo) {
                             StopPlaying();
                         }
                     }
@@ -2362,8 +2394,8 @@ namespace Banshee
         
         private void ShowSourceProperties(Source source)
         {
-            switch(source.Type) {
-                case SourceType.Ipod:
+           /* switch(source.Type) {
+                case SourceType.Dap:
                     IpodSource ipodSource = source as IpodSource;
                     IPod.Device device = ipodSource.Device;
                     IpodPropertiesDialog propWin = 
@@ -2375,7 +2407,7 @@ namespace Banshee
                     source.Rename(device.Name);
                     sourceView.QueueDraw();
                     break;
-            }
+            }*/
         }
         
         private void StopPlaying()
@@ -2437,14 +2469,14 @@ namespace Banshee
                 HBox syncing_box = new HBox();
                 syncing_container.Add(syncing_box);
                 syncing_box.Spacing = 20;
-                syncing_box.PackStart(ipod_syncing_image, false, false, 0);
+                syncing_box.PackStart(dap_syncing_image, false, false, 0);
                 Label syncing_label = new Label();
                                                 
                 syncing_container.ModifyBg(StateType.Normal, new Color(0, 0, 0));
                 syncing_label.ModifyFg(StateType.Normal, new Color(160, 160, 160));
             
                 syncing_label.Markup = "<big><b>" + GLib.Markup.EscapeText(
-                    Catalog.GetString("Synchronizing your iPod, Please Wait...")) + "</b></big>";
+                    Catalog.GetString("Synchronizing your Device, Please Wait...")) + "</b></big>";
                 syncing_box.PackStart(syncing_label, false, false, 0);
             }
             
