@@ -33,6 +33,8 @@ using System.Threading;
 using Gtk;
 using Sql;
 
+using Banshee.Base;
+
 namespace Banshee
 {
     public enum RepeatMode {
@@ -44,7 +46,7 @@ namespace Banshee
     public class PlaylistModel : ListStore, IPlaybackModel
     {
         private static int uid;
-        private long totalDuration = 0;
+        private TimeSpan totalDuration = new TimeSpan(0);
         
         private ArrayList trackInfoQueue;
         private bool trackInfoQueueLocked = false;
@@ -144,7 +146,7 @@ namespace Banshee
                 return;
 
             totalDuration += ti.Duration;
-            AppendValues(ti);
+            ti.TreeIter = AppendValues(ti);
             
             if(raiseUpdate) {
                 RaiseUpdated(this, new EventArgs());
@@ -188,11 +190,11 @@ namespace Banshee
             RaiseUpdated(this, new EventArgs());
         }
         
-        public void LoadFromIpodSource(IpodSource ipodSource)
+        public void LoadFromDapSource(DapSource dapSource)
         {
             ClearModel();
             
-            foreach(IpodTrackInfo track in ipodSource.Tracks) {
+            foreach(Banshee.Dap.DapTrackInfo track in dapSource.Device) {
                 AddTrack(track);
             }
             
@@ -387,12 +389,11 @@ namespace Banshee
             Core.Library.TransactionManager.Cancel(typeof(FileLoadTransaction));
             trackInfoQueue.Clear();
         
-            totalDuration = 0;
+            totalDuration = new TimeSpan(0);
             playingIter = TreeIter.Zero;
             Clear();
                 
-            if(Updated != null && 
-                Core.Instance.MainThread.Equals(Thread.CurrentThread))
+            if(Updated != null && ThreadAssist.InMainThread)
                 Updated(this, new EventArgs());
         }
         
@@ -436,6 +437,7 @@ namespace Banshee
         {
             TrackInfo ti = IterTrackInfo(iter);
             totalDuration -= ti.Duration;
+            ti.TreeIter = TreeIter.Zero;
             Remove(ref iter);
             RaiseUpdated(this, new EventArgs());
         }
@@ -449,7 +451,7 @@ namespace Banshee
                 handler(o, args);
         }
         
-        public long TotalDuration 
+        public TimeSpan TotalDuration 
         {
             get {
                 return totalDuration;
