@@ -36,6 +36,9 @@ using Gtk;
 using Gdk;
 using Pango;
 
+using Banshee.Base;
+using Banshee.Dap;
+
 namespace Banshee
 {
     public class LoaderAdditionArgs : EventArgs
@@ -261,8 +264,10 @@ namespace Banshee
         public int TimeTreeIterCompareFunc(TreeModel _model, TreeIter a,
             TreeIter b)
         {
-            return LongFieldCompare(model.IterTrackInfo(a).Duration,
-                model.IterTrackInfo(b).Duration);
+            //return LongFieldCompare(model.IterTrackInfo(a).Duration,
+            //    model.IterTrackInfo(b).Duration);
+                
+            return model.IterTrackInfo(a).Duration.CompareTo(model.IterTrackInfo(b).Duration);
         }
         
         public int RatingTreeIterCompareFunc(TreeModel _model, TreeIter a,
@@ -275,8 +280,8 @@ namespace Banshee
         public int PlayCountTreeIterCompareFunc(TreeModel _model, TreeIter a,
             TreeIter b)
         {
-            return LongFieldCompare((long)model.IterTrackInfo(a).NumberOfPlays,
-                (long)model.IterTrackInfo(b).NumberOfPlays);
+            return LongFieldCompare((long)model.IterTrackInfo(a).PlayCount,
+                (long)model.IterTrackInfo(b).PlayCount);
         }
         
         public int LastPlayedTreeIterCompareFunc(TreeModel _model, TreeIter a,
@@ -325,10 +330,10 @@ namespace Banshee
             renderer.Foreground = null;
             
             TrackInfo ti = model.IterTrackInfo(iter);
-            if(ti.GetType() != typeof(IpodTrackInfo)) 
+            if(ti.GetType() != typeof(DapTrackInfo)) 
                 return;
                 
-            if((ti as IpodTrackInfo).NeedSync)
+            if((ti as DapTrackInfo).NeedSync)
                 renderer.Foreground = "blue";
         }
         
@@ -362,19 +367,19 @@ namespace Banshee
                 return;
             }
             
-            if(model.Source.GetType() != typeof(IpodSource)) {
+            if(model.Source.GetType() != typeof(DapSource)) {
                 renderer.Pixbuf = null;
                 return; 
             }
             
             TrackInfo ti = model.IterTrackInfo(iter);
             
-            if(ti.GetType() != typeof(IpodTrackInfo)) {
+            if(ti.GetType() != typeof(DapTrackInfo)) {
                 renderer.Pixbuf = null;
                 return;
             }
             
-            IpodTrackInfo iti = ti as IpodTrackInfo;
+            DapTrackInfo iti = ti as DapTrackInfo;
             renderer.Pixbuf = iti.NeedSync
                 ? syncNeededPixbuf
                 : (iti.CanPlay ? null : songDrmedPixbuf); 
@@ -413,15 +418,15 @@ namespace Banshee
         {
             TrackInfo Track = model.IterTrackInfo(iter);
             SetRendererAttributes((CellRendererText)cell, 
-                Track.Duration < 0 ? Catalog.GetString("N/A") : 
-                String.Format("{0}:{1}", Track.Duration / 60, 
-                (Track.Duration % 60).ToString("00")), iter);
+                Track.Duration.TotalSeconds < 0.0 ? Catalog.GetString("N/A") : 
+                String.Format("{0}:{1}", Track.Duration.Minutes, 
+                (Track.Duration.Seconds).ToString("00")), iter);
         }
         
         protected void TrackCellPlayCount(TreeViewColumn tree_column,
             CellRenderer cell, TreeModel tree_model, TreeIter iter)
         {
-            uint plays = model.IterTrackInfo(iter).NumberOfPlays;
+            uint plays = model.IterTrackInfo(iter).PlayCount;
             SetRendererAttributes((CellRendererText)cell, 
                 plays > 0 ? Convert.ToString(plays) : "", 
                 iter);
