@@ -34,6 +34,9 @@ using System.Runtime.InteropServices;
 using System.Threading;
 using Mono.Unix;
 
+using Banshee.Widgets;
+using Banshee.Base;
+
 namespace Banshee
 {
     public delegate void CdRipProgressCallback(IntPtr ripper, int seconds,
@@ -110,7 +113,7 @@ namespace Banshee
                 return;
                 
             AudioCdRipperProgressArgs args = new AudioCdRipperProgressArgs();
-            args.TotalSeconds = (int)currentTrack.Duration;
+            args.TotalSeconds = (int)currentTrack.Duration.TotalSeconds;
             args.SecondsEncoded = seconds;
             args.Track = currentTrack;
             
@@ -178,7 +181,7 @@ namespace Banshee
             }
             
             tracks.Add(track);
-            totalCount += track.Duration;
+            totalCount += (int)track.Duration.TotalSeconds;
         }
         
         public void Run()
@@ -216,7 +219,7 @@ namespace Banshee
                     break;
          
                 status = String.Format(Catalog.GetString(
-                    "Ripping {0} of {1} : {2} - {3}"), current++, QueueSize,
+                    "Importing {0} of {1} : {2} - {3}"), current++, QueueSize,
                     track.Artist, track.Title);
                 user_event.Message = status;
                     
@@ -226,7 +229,7 @@ namespace Banshee
                     break;
                 }
                 
-                overallProgress += (int)track.Duration;
+                overallProgress += (int)track.Duration.TotalSeconds;
                 
                 if(!user_event.IsCancelRequested) {
                     TrackInfo lti;
